@@ -5,8 +5,8 @@ Created on Sun Oct  2 21:28:02 2022
 @author: lidon
 """
 
-from vector import*
-from linked_list import*
+from .vector import*
+from .linked_list import*
 
 
 class queue(linked_list):
