@@ -5,8 +5,8 @@ Created on Sat Oct  1 19:18:30 2022
 @author: lidon
 """
 
-from vector import*
-from vectorADT import*
+from .vector import*
+from .vectorADT import*
 
 class stack(vector):
     def __init__(self,elements):
